import { MigrationInterface, QueryRunner, TableColumn } from "typeorm";
import { getDefaultByORM, getTypeByORM } from "./ormHelper";
import { newsletter } from "../entity/club/newsletter/newsletter";

export class NewsletterColumnType1744351418751 implements MigrationInterface {
  name = "NewsletterColumnType1744351418751";

  public async up(queryRunner: QueryRunner): Promise<void> {
    let newsletters = await queryRunner.manager
      .getRepository("newsletter")
      .find({ select: { id: true, newsletterTitle: true, newsletterSignatur: true } });

    await queryRunner.dropColumn("newsletter", "newsletterTitle");
    await queryRunner.dropColumn("newsletter", "newsletterSignatur");

    await queryRunner.addColumn(
      "newsletter",
      new TableColumn({ name: "newsletterTitle", ...getTypeByORM("text"), default: getDefaultByORM("string") })
    );
    await queryRunner.addColumn(
      "newsletter",
      new TableColumn({ name: "newsletterSignatur", ...getTypeByORM("text"), default: getDefaultByORM("string") })
    );

    await queryRunner.manager.getRepository("newsletter").save(newsletters);
  }

  public async down(queryRunner: QueryRunner): Promise<void> {
    let newsletters = await queryRunner.manager
      .getRepository("newsletter")
      .find({ select: { id: true, newsletterTitle: true, newsletterSignatur: true } });

    await queryRunner.dropColumn("newsletter", "newsletterTitle");
    await queryRunner.dropColumn("newsletter", "newsletterSignatur");

    await queryRunner.addColumn(
      "newsletter",
      new TableColumn({ name: "newsletterTitle", ...getTypeByORM("varchar"), default: getDefaultByORM("string") })
    );
    await queryRunner.addColumn(
      "newsletter",
      new TableColumn({ name: "newsletterSignatur", ...getTypeByORM("varchar"), default: getDefaultByORM("string") })
    );

    await queryRunner.manager.getRepository("newsletter").save(newsletters);
  }
}
